@@ -2,6 +2,7 @@ from unittest import mock
 import pytest
 import requests_mock
 
+from conftest import IP_ADDR
 from soco import SoCo
 from soco.data_structures import to_didl_string
 from soco.exceptions import (
@@ -13,35 +14,6 @@ from soco.exceptions import (
 from soco.groups import ZoneGroup
 from soco.xml import XML
 
-IP_ADDR = "192.168.1.101"
-
-
-@pytest.fixture()
-def moco():
-    """A mock soco with fake services and hardcoded is_coordinator.
-
-    Allows calls to services to be tracked. Should not cause any network
-    access
-    """
-    services = (
-        "AVTransport",
-        "RenderingControl",
-        "DeviceProperties",
-        "ContentDirectory",
-        "ZoneGroupTopology",
-        "GroupRenderingControl",
-    )
-    patchers = [mock.patch("soco.core.{}".format(service)) for service in services]
-    for patch in patchers:
-        patch.start()
-    with mock.patch(
-        "soco.SoCo.is_coordinator", new_callable=mock.PropertyMock
-    ) as is_coord:
-        is_coord = True  # noqa: F841
-        yield SoCo(IP_ADDR)
-    for patch in reversed(patchers):
-        patch.stop()
-
 
 @pytest.fixture()
 def moco_only_on_master():
@@ -1280,7 +1252,7 @@ class TestRenderingControl:
 
     def test_soco_audio_delay(self, moco):
         moco._is_soundbar = False
-        assert moco.audio_delay == None
+        assert moco.audio_delay is None
         assert not moco.renderingControl.GetEQ.called
 
         with pytest.raises(NotSupportedException):
@@ -1355,6 +1327,69 @@ class TestRenderingControl:
             [("InstanceID", 0), ("Channel", "RF"), ("DesiredVolume", 100)]
         )
 
+    @pytest.mark.parametrize(
+        "prop,variable,type,min,max",
+        [
+            ("surround_enabled", "SurroundEnable", bool, None, None),
+            ("surround_full_volume_enabled", "SurroundMode", bool, None, None),
+            ("surround_volume_tv", "SurroundLevel", int, -15, 15),
+            ("surround_volume_music", "MusicSurroundLevel", int, -15, 15),
+        ],
+    )
+    def test_soco_surround_settings(self, moco, prop, variable, type, min, max):
+        """Test the surround settings.
+
+        This performs the following checks:
+        * For boolean values, check toggling and payloads
+        * For ranged int values, check the ranges and payloads.
+        """
+
+        def _assert_seteq_call(prop, variable, value, type):
+            desired_value = value
+            setattr(moco, prop, value)
+
+            moco.renderingControl.SetEQ.assert_any_call(
+                [
+                    ("InstanceID", 0),
+                    ("EQType", variable),
+                    ("DesiredValue", int(desired_value)),
+                ]
+            )
+
+            moco.renderingControl.GetEQ.return_value = {
+                "CurrentValue": int(desired_value)
+            }
+            if type == bool:
+                assert getattr(moco, prop) == bool(value)
+            elif type == int:
+                assert getattr(moco, prop) == value
+
+            moco.renderingControl.GetEQ.assert_any_call(
+                [("InstanceID", 0), ("EQType", variable)]
+            )
+            moco.renderingControl.SetEQ.reset_mock()
+            moco.renderingControl.GetEQ.reset_mock()
+
+        with mock.patch(
+            "soco.SoCo.is_soundbar", new_callable=mock.PropertyMock
+        ) as mock_is_soundbar:
+            mock_is_soundbar = True  # noqa: F841
+
+            if type == bool:
+                for target in [True, False]:
+                    _assert_seteq_call(prop, variable, target, type)
+
+            elif type == int:
+                for target in [min, max]:
+                    _assert_seteq_call(prop, variable, target, type)
+
+                for target in [min - 5, max + 5]:
+                    with pytest.raises(ValueError):
+                        setattr(moco, prop, target)
+
+            else:
+                raise Exception("unhandled type %s" % type)
+
 
 class TestDeviceProperties:
     def test_soco_status_light(self, moco):
